@@ -238,19 +238,41 @@ class DockerRegistry(object):
 
 class Client(object):
 
-    def __init__(self, url=STAGING_API_URL, key=None, insecure=False):
+    def __init__(
+        self, url=STAGING_API_URL, key=None, insecure=False, user_agent=None
+    ):
         self.url = url
         self.insecure = insecure
         self.key = key
+        self.user_agent = user_agent
 
     @property
     def requests_session(self):
         session = RequestsSession(self.url)
         session.verify = not self.insecure
+
         session.headers.update({
             'x-api-key': self.key
         })
 
+        if self.user_agent:
+            user_agent_header = {}
+            name = self.user_agent.get('name')
+            version = self.user_agent.get('version')
+
+            if name and version:
+                user_agent_header_fmt = "{name}/{version}"
+                user_agent_header_content = user_agent_header_fmt.format(
+                    name=name,
+                    version=version,
+                )
+
+                user_agent_header = {
+                    'User-Agent': user_agent_header_content
+                }
+
+            session.headers.update(user_agent_header)
+
         return session
 
     @property
