@@ -1,5 +1,6 @@
 import click
-
+# TODO: refactoring. all deploy create share some behavior
+from convisoappsec.flow.util import project_metrics
 from convisoappsec.flow.version_searchers import TimeBasedVersionSearcher
 from convisoappsec.flow.version_control_system_adapter import GitAdapter
 from convisoappsec.flowcli.context import pass_flow_context
@@ -53,6 +54,7 @@ def time_(
             current_version=current_version,
             previous_version=previous_version,
             diff_content=diff_content,
+            project_metrics=project_metrics(repository_dir)
         )
 
         click.echo(
