@@ -7,21 +7,21 @@ import docker
 
 class SASTBox(object):
     REGISTRY = 'docker.convisoappsec.com'
-    TAG = 'latest'
+    REPOSITORY_NAME = 'sastbox'
+    DEFAULT_TAG = 'latest'
     CONTAINER_REPORTS_DIR = '/reports'
     CONTAINER_CODE_DIR = '/code'
-
     WORKSPACE_REPORT_PATH = ["reports"]
     JSON_REPORT_PATTERN = '*.jsonreporter*.json'
     SUCCESS_EXIT_CODE = 0
     USER_ENV_VAR = "USER"
 
-    def __init__(self):
+    def __init__(self, tag=None):
         self.docker = docker.from_env(
             version="auto"
         )
-
         self.container = None
+        self.tag = tag or self.DEFAULT_TAG
 
     def login(self, password, username='AWS'):
         login_args = {
@@ -44,7 +44,7 @@ class SASTBox(object):
     @property
     def size(self):
         registry_data = self.docker.images.get_registry_data(
-            "{image}:{tag}".format(image=self.image, tag=self.TAG)
+            self.image
         )
 
         descriptor = registry_data.attrs.get('Descriptor', {})
@@ -61,7 +61,7 @@ class SASTBox(object):
         size = self.size
         layers = {}
         for line in self.docker.api.pull(
-            self.image, tag=self.TAG, stream=True, decode=True
+            self.repository, tag=self.tag, stream=True, decode=True
         ):
             status = line.get('status', '')
             detail = line.get('progressDetail', {})
@@ -156,9 +156,19 @@ class SASTBox(object):
 
         return self._list_reports_paths(tempdir)
 
+    @property
+    def repository(self):
+        return "{registry}/{repository_name}".format(
+            registry=self.REGISTRY,
+            repository_name=self.REPOSITORY_NAME,
+        )
+
     @property
     def image(self):
-        return "%s/sastbox" % self.REGISTRY
+        return "{repository}:{tag}".format(
+            repository=self.repository,
+            tag=self.tag,
+        )
 
     def __del__(self):
         with suppress(Exception):
